from distutils.core import setup

setup(
    name='Starbucks',
    packages=['starbucks'],
    version='0.0.1',
    description='Unoffical Starbucks API.',
    long_description=open('README.rst').read(),
    license='BSD License',
    author='Minsoo Park',
    author_email='minsoo1003@gmail.com',
    url='https://github.com/minsoopark/starbucks-py',
    keywords=['Starbucks'],
)
